Stan Math Library: stan/math/prim/mat/fun/diagonal.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
diagonal.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
Eigen::Matrix< T, Eigen::Dynamic, 1 > | stan::math::diagonal (const Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > &m)
| Return a column vector of the diagonal elements of the specified matrix. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.